@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 11055 2018-05-14 09:46:32Z Lavender $
+# $Id: __init__.py 11224 2018-09-09 11:32:06Z Lavender $
 #
 # Copyright (c) 2018 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $ (last)
-# $Date: 2018-05-14 17:46:32 +0800 (週一, 14 五月 2018) $
-# $Revision: 11055 $
+# $Date: 2018-09-09 19:32:06 +0800 (週日, 09 九月 2018) $
+# $Revision: 11224 $
 
 from django.conf import settings as _settings
 from django.utils.translation import ugettext_lazy as _
@@ -23,6 +23,8 @@ class settings(object):
         "cms_oscar/Featured.html"
     ZEPHYRUS_OSCAR_LATEST_DEFAULT_TEMPLATE = \
         "cms_oscar/Latest.html"
+    ZEPHYRUS_OSCAR_OFFER_DEFAULT_TEMPLATE = \
+        "cms_oscar/Offer.html"
 
     ZEPHYRUS_OSCAR_FEATURED_TEMPLATES = [
         (ZEPHYRUS_OSCAR_FEATURED_DEFAULT_TEMPLATE, _("Default")),
@@ -32,6 +34,10 @@ class settings(object):
         (ZEPHYRUS_OSCAR_LATEST_DEFAULT_TEMPLATE, _("Default")),
     ]
 
+    ZEPHYRUS_OSCAR_OFFER_TEMPLATES = [
+        (ZEPHYRUS_OSCAR_OFFER_DEFAULT_TEMPLATE, _("Default")),
+    ]
+
     if hasattr(_settings, 'ZEPHYRUS_OSCAR_FEATURED_TEMPLATES'):
         for ele in _settings.ZEPHYRUS_OSCAR_FEATURED_TEMPLATES:
             if not ele[0] == ZEPHYRUS_OSCAR_FEATURED_DEFAULT_TEMPLATE:
@@ -42,3 +48,8 @@ class settings(object):
             if not ele[0] == ZEPHYRUS_OSCAR_LATEST_DEFAULT_TEMPLATE:
                 ZEPHYRUS_OSCAR_LATEST_TEMPLATES.append(ele)
 
+    if hasattr(_settings, 'ZEPHYRUS_OSCAR_OFFER_TEMPLATES'):
+        for ele in _settings.ZEPHYRUS_OSCAR_OFFER_TEMPLATES:
+            if not ele[0] == ZEPHYRUS_OSCAR_OFFER_DEFAULT_TEMPLATE:
+                ZEPHYRUS_OSCAR_OFFER_TEMPLATES.append(ele)
+
